import bridges.connect.Bridges;
import bridges.connect.DataSource;
import bridges.base.BSTElement;
import bridges.data_src_dependent.EarthquakeUSGS;
import java.util.List;


public class bst_eq {
	public static void main(String[] args) throws Exception {

		//create the Bridges object
		Bridges bridges = new Bridges(37, "BRIDGES_USER_ID", "BRIDGES_API_KEY");

		// set title, description
		bridges.setTitle("A Binary Search Tree Example with Earthquake Data");
		bridges.setDescription("This example illustrates retrieving USGS earthquake data records and inserted into a binary search tree. Attributes of the quake are displayed at each node.");

		// set max quakes for this example
		final int MaxQuakes = 25;

		// Retrieve a list of MaxQuakes earthquake records 
		// from USGS using BRIDGES
		DataSource ds = bridges.getDataSource();
		List<EarthquakeUSGS> eqlist = ds.getEarthquakeUSGSData(MaxQuakes);


		// create a binary search tree and insert the EQ records into the tree
		BSTElement<Double, EarthquakeUSGS> root = null;
		for (int k = 0; k < MaxQuakes; k++) {
			BSTElement<Double, EarthquakeUSGS> bst_node =
				new BSTElement<Double, EarthquakeUSGS>(eqlist.get(k).getMagnitude(), eqlist.get(k));
			// set label of the node
			bst_node.setLabel(eqlist.get(k).getTitle() + "\n\nLat/Long: ( " +
				eqlist.get(k).getLatit() + "," + eqlist.get(k).getLongit() + " )\n\n" +
				eqlist.get(k).getTime());
			root = insert_R (root, bst_node);
		}

		// set some visual attributes
		root.setColor("red");
		root.setSize(30.);

		styleLargest(root);
 
		//set visualizer type
		bridges.setDataStructure(root);
		// visualize the tree
		bridges.visualize();
	}
	// recursive insert method to insert nodes into a binary search tree
	public static BSTElement<Double, EarthquakeUSGS> insert_R (BSTElement<Double, EarthquakeUSGS> rt,
		BSTElement<Double, EarthquakeUSGS> new_el) {
		if (rt == null)
			return new_el;
		else if (new_el.getKey() < rt.getKey())
			rt.setLeft(insert_R(rt.getLeft(), new_el));
		else
			rt.setRight(insert_R(rt.getRight(), new_el));
		return rt;
	}

	public static void styleLargest (BSTElement<Double, EarthquakeUSGS> rt) {
		while (rt != null) {
			if (rt.getRight() == null) { 
				// the largest has been reached, color the node
				rt.setColor("orange");
				rt.setSize (30.);
			}
			rt = rt.getRight();
		}
	}
}
